@@ -7,7 +7,7 @@ pip install easygame -i https://pypi.org/project
 导入:
 import easygame as eg
 
-作者: stripe-python & Sunny
+作者: stripe-python
 开源作品，已上传至pypi
 """
 
